@@ -1,4 +1,5 @@
-#! /usr/bin/env python
+#!/usr/bin/env python
+
 """
 A script for reducing the number of channels in a UV data set by coherently
 adding adjacent channels together.
@@ -9,6 +10,8 @@ Revisions:
     12/11/07    arp Ported to new miriad file interface
 """
 
+from __future__ import print_function, division, absolute_import
+
 import aipy as a, sys, os, numpy as np, optparse
 
 o = optparse.OptionParser()
@@ -26,21 +29,21 @@ opts, args = o.parse_args(sys.argv[1:])
 
 uvo = None
 for uvfile in args:
-    print uvfile,'->',uvfile+'m'
+    print(uvfile,'->',uvfile+'m')
     uvi = a.miriad.UV(uvfile)
     sfreq,sdf,nchan = uvi['sfreq'], uvi['sdf'], uvi['nchan']
     newsfreq = sfreq + ((nchan/opts.nchan) * sdf) / 2
     newsdf = sdf * (nchan/opts.nchan)
-    
+
     if uvo is None:
         uvofile = uvfile+'m'
         if os.path.exists(uvofile):
-            print uvofile, 'exists, skipping.'
+            print(uvofile, 'exists, skipping.')
             continue
         uvo = a.miriad.UV(uvofile, status='new')
         if nchan != opts.nchan:
-            uvo.init_from_uv(uvi, override={'nchan':opts.nchan, 
-                'sfreq':newsfreq, 'sdf':newsdf, 'nschan':opts.nchan, 
+            uvo.init_from_uv(uvi, override={'nchan':opts.nchan,
+                'sfreq':newsfreq, 'sdf':newsdf, 'nschan':opts.nchan,
                 'freq':newsfreq, 'nchan0':opts.nchan, },)
         else: uvo.init_from_uv(uvi)
 
@@ -50,7 +53,7 @@ for uvfile in args:
             d.shape = (opts.nchan, nchan/opts.nchan)
             d = d.sum(axis=1)
             f.shape = (opts.nchan, nchan/opts.nchan)
-            f = np.logical_not(f).astype(np.int).sum(axis=1)
+            f = np.logical_not(f).astype(np.int_).sum(axis=1)
             d /= f.clip(1,np.Inf)
             if opts.careful_flag: f = np.where(f < nchan/opts.nchan, 1, 0)
             elif opts.dont_flag: f = np.where(f < 1, 1, 0)
@@ -60,10 +63,9 @@ for uvfile in args:
             append2hist='COMB_FREQ: nchan=%d careful=%s dont=%s unify=%s\n' % \
                 (opts.nchan, opts.careful_flag, opts.dont_flag, opts.unify))
     else:
-        uvo.pipe(uvi, 
+        uvo.pipe(uvi,
             append2hist='COMB_FREQ: nchan=%d careful=%s dont=%s unify=%s\n' % \
                 (opts.nchan, opts.careful_flag, opts.dont_flag, opts.unify))
     if not opts.unify:
         del(uvo)
         uvo = None
-    
