@@ -4,6 +4,8 @@
 Do a one iteration delay-solving algorithm.
 """
 
+from __future__ import print_function, division, absolute_import
+
 import aipy as a
 import numpy as np
 from matplotlib import pylab as pl
@@ -55,7 +57,7 @@ DD = {}
 bl_len = {}
 AntNos = []
 for uvfile in args:
-    print 'Reading',uvfile
+    print('Reading',uvfile)
     uv = a.miriad.UV(uvfile)
     for (uvw,t,(i,j)),d,f in uv.all(raw=True):
         if i == j: continue
@@ -66,7 +68,7 @@ for uvfile in args:
         if pol == 'yx' : continue
         if i in FlagAnt: continue
         if j in FlagAnt: continue
-        if not pol in DD.keys(): 
+        if not pol in DD.keys():
             DD[pol] = {}
         if not (i,j) in DD[pol].keys(): DD[pol][(i,j)] = np.zeros(uv['nchan'],dtype=np.complex)
         #Delay transform
@@ -96,8 +98,8 @@ for pol in pols:
         #multiply by some prior.
         for i,x in enumerate(DD[pol][bl]):
             if x == 1: D_ij[pol][bl] = delays[i]
-        #W_ij[pol][bl] = 1./(np.std(DD[pol][bl])**2) 
-        W_ij[pol][bl] = 1. 
+        #W_ij[pol][bl] = 1./(np.std(DD[pol][bl])**2)
+        W_ij[pol][bl] = 1.
 
 #Construct matrices to do linear algebra and shit.
 
@@ -106,7 +108,7 @@ for pol in pols:
     A = np.zeros((Nbl+1,Nant))
     W = np.zeros((Nbl+1,Nbl+1))
     b = np.zeros(Nbl+1)
-        
+
     #populatin the countryside, populatin the villages!
     index = 0
     for i,ant1 in enumerate(AntNos):
@@ -114,12 +116,12 @@ for pol in pols:
             if not (ant1,ant2) in D_ij[pol].keys(): continue
             #if j <= i: continue
             b[index] = D_ij[pol][(ant1,ant2)]
-            A[index,i],A[index,j] = 1.,-1.    
+            A[index,i],A[index,j] = 1.,-1.
             W[index,index] = W_ij[pol][(ant1,ant2)]
             index += 1
     #Set Constraints
     W /= np.sum(W)
-        
+
     Tau[pol] = np.dot(np.linalg.inv(np.dot(np.dot(A.T,W),A)),np.dot(np.dot(A.T,W),b))
     Tau[pol] -= np.mean(Tau[pol])
 
@@ -134,7 +136,7 @@ if not opts.cal is None:
             if pol != pols[-1]: calstr += ', '
         calstr += ' }'
         if i != len(AntNos)-1: calstr += ','
-        print calstr
+        print(calstr)
 else:
     for i,ant in enumerate(AntNos):
         calstr = str(ant)+' : { '
@@ -144,26 +146,26 @@ else:
             if pol != pols[-1]: calstr += ', '
         calstr += ' }'
         if i != len(AntNos)-1: calstr += ','
-        print calstr
+        print(calstr)
 
-print 'Computing time =', time() - t0,'s for',Nbl,'baselines.'
+print('Computing time =', time() - t0,'s for',Nbl,'baselines.')
 
 
 if opts.plots:
-    print 'Generating plots.... this may take a while...'
+    print('Generating plots.... this may take a while...')
     figcnt = 0
-    AntNos = np.array(AntNos) 
-    
+    AntNos = np.array(AntNos)
+
     def issubplotedge(rows,cols,index):
         inds = np.arange(1,cols*rows+1,1)
         inds.shape = (rows,cols)
         left = not np.argwhere(inds==index).squeeze()[1]
         bottom = not (np.argwhere(inds==index).squeeze()[0]+1)%rows
         return left,bottom
-    
+
     for pol in pols:
         pl.figure(figcnt)
-        
+
         nplots = len(DD[pol].keys())
         rows = Nant
         cols = Nant
@@ -174,14 +176,14 @@ if opts.plots:
             #Make the plots
             i,j = np.argwhere(AntNos==bl[0]).squeeze(),np.argwhere(AntNos==bl[1]).squeeze()
             plindex = i*Nant+j
-            
+
             ax = pl.subplot(rows,cols,plindex)
-           
+
             pl.vlines(D_ij[pol][bl]/bl_len[bl],0,1.1,color='k')
             pl.vlines((Tau[pol][i]-Tau[pol][j])/bl_len[bl],0,1.1,color='r')
             pl.vlines((-1,1),0,1.1,linestyles='dotted',color='k')
             pl.plot(delays/bl_len[bl],DD[pol][bl],'b')
-           
+
             pl.xlim([-1.5,1.5])
             pl.ylim([0,1.1])
             pl.yticks([])
@@ -189,7 +191,7 @@ if opts.plots:
 
             if i == 0: pl.text(0.5,1.2,str(AntNos[j]),transform=ax.transAxes)
             if j == Nant-1: pl.text(1.2,0.5,str(AntNos[i]),transform=ax.transAxes)
-    
+
         #Give a sample plot
         pl.subplot(337)
         bl = bls[0]
@@ -207,7 +209,7 @@ if opts.plots:
         pl.subplots_adjust(wspace=0,hspace=0,top=0.95,bottom=0.05)
         pl.draw()
         figcnt += 1
-        
+
     #Plot a matrix of all delays
     for pol in pols:
         pl.figure(figcnt)
@@ -221,8 +223,8 @@ if opts.plots:
         pl.colorbar()
         pl.draw()
         figcnt += 1
-        
-    
+
+
     #Delay vs. Antenna
     pl.figure(figcnt)
     for pol in pols:
