@@ -1,4 +1,5 @@
-#! /usr/bin/env python
+#!/usr/bin/env python
+
 """
 This is a general-purpose script for making images from MIRIAD UV files.  Data
 (optionally selected for baseline, channel) are read from the file, phased
@@ -6,6 +7,8 @@ to a provided position, normalized for passband/primary beam effects, gridded
 to a UV matrix, and imaged
 """
 
+from __future__ import print_function, division, absolute_import
+
 import aipy as a, numpy as np, sys, optparse, ephem, os
 
 o = optparse.OptionParser()
@@ -70,12 +73,12 @@ outputs = opts.output.split(',')
 if opts.src == 'zen':
     srcs = [a.phs.RadioFixedBody(aa.sidereal_time(), aa.lat, name='zen')]
     cat = a.phs.SrcCatalog(srcs)
-elif not opts.src is None: 
+elif not opts.src is None:
     srclist,cutoff,catalogs = a.scripting.parse_srcs(opts.src, opts.cat)
     cat = a.cal.get_catalog(opts.cal, srclist, cutoff, catalogs)
 else:
     ras,decs = a.map.facet_centers(opts.facets, ncrd=2)
-    srcs = [a.phs.RadioFixedBody(ra,dec,name=str(i)) 
+    srcs = [a.phs.RadioFixedBody(ra,dec,name=str(i))
         for i,(ra,dec) in enumerate(zip(ras,decs))]
     cat = a.phs.SrcCatalog(srcs)
 
@@ -85,9 +88,9 @@ if opts.list_facets:
     for cnt, src in enumerate(cat.values()):
         cen = ephem.Equatorial(src.ra, src.dec, epoch=aa.epoch)
         cen = ephem.Equatorial(cen, epoch=ephem.J2000)
-        print '# %3d >  RA=%s  DEC=%s  (%f, %f in deg)' % \
-            (cnt, cen.ra, cen.dec, 
-            a.img.rad2deg*cen.ra, a.img.rad2deg*cen.dec)
+        print('# %3d >  RA=%s  DEC=%s  (%f, %f in deg)' % \
+            (cnt, cen.ra, cen.dec,
+            a.img.rad2deg*cen.ra, a.img.rad2deg*cen.dec))
 
 # Generate the image object that will be used.
 us,vs,ws,ds,wgts = [],[],[],[],[]
@@ -99,7 +102,7 @@ L,M = im.get_LM()
 DIM = int(opts.size/opts.res)
 n_ints = 0
 
-#print 'Calculating image of primary beam'
+#print('Calculating image of primary beam')
 #top = im.get_eq(0, aa.lat)
 #mask = top[0].mask
 #m = a.coord.eq2top_m(0, aa.lat)
@@ -110,13 +113,13 @@ n_ints = 0
 #aa.select_chans(chans)
 #d.shape = (DIM,DIM)
 #bm_im = np.where(mask, 0, d)
-#print 'done'
+#print('done')
 
 # Define a quick function writing an image to a FITS file
 def fname(ftag, cnt): return '%s.%s.fits' % (opts.fmt % cnt, ftag)
 def to_fits(ftag,i,src,cnt,history=''):
     filename = fname(ftag,cnt)
-    print 'Saving data to', filename
+    print('Saving data to', filename)
     while len(i.shape) < 4: i.shape = i.shape + (1,)
     cen = ephem.Equatorial(src.ra, src.dec, epoch=aa.epoch)
     # We precess the coordinates of the center of the image here to
@@ -135,7 +138,7 @@ def to_fits(ftag,i,src,cnt,history=''):
         freq=np.average(aa[0].beam.afreqs),history=history)
 
 def grid_it(im,us,vs,ws,ds,wgts):
-    #print 'Gridding %d integrations' % n_ints
+    #print('Gridding %d integrations' % n_ints)
     sys.stdout.write('|'); sys.stdout.flush()
     if len(ds) == 0: raise ValueError('No data to use.')
     ds,wgts = np.concatenate(ds), np.concatenate(wgts).flatten()
@@ -147,11 +150,11 @@ def grid_it(im,us,vs,ws,ds,wgts):
 
 def img_it(im):
     global n_ints
-    #print 'Imaging with %d integrations' % n_ints
+    #print('Imaging with %d integrations' % n_ints)
     n_ints = 0
     # Form dirty images/beams
-    uvs = a.img.recenter(np.abs(im.uv).astype(np.float), (DIM/2,DIM/2))
-    bms = a.img.recenter(np.abs(im.bm[0]).astype(np.float), (DIM/2,DIM/2))
+    uvs = a.img.recenter(np.abs(im.uv).astype(np.float64), (DIM/2,DIM/2))
+    bms = a.img.recenter(np.abs(im.bm[0]).astype(np.float64), (DIM/2,DIM/2))
     dim = im.image((DIM/2, DIM/2))
     dbm = im.bm_image(term=0, center=(DIM/2,DIM/2))
     return uvs,bms, dim,dbm
@@ -161,8 +164,8 @@ imgcnt = opts.cnt
 for srccnt, s in enumerate(cat.values()):
     if srccnt < opts.skip: continue
     s.compute(aa)
-    print '%d / %d' % (srccnt + 1, len(cat.values()))
-    print 'Pointing (ra, dec):', s.ra, s.dec
+    print('%d / %d' % (srccnt + 1, len(cat.values())))
+    print('Pointing (ra, dec):', s.ra, s.dec)
     src = a.fit.SrcCatalog([s])
     # Gather data
     snapcnt,curtime = 0, None
@@ -198,7 +201,7 @@ for srccnt, s in enumerate(cat.values()):
                       else:
                           im = a.img.ImgW(opts.size, opts.res, mf_order=0, wres=opts.wres)
                       if opts.src == 'zen':
-                          s = a.phs.RadioFixedBody(aa.sidereal_time(), 
+                          s = a.phs.RadioFixedBody(aa.sidereal_time(),
                               aa.lat, name='zen')
                           src = a.fit.SrcCatalog([s])
               curtime = t
@@ -220,10 +223,10 @@ for srccnt, s in enumerate(cat.values()):
           if not opts.skip_bm:
               # Calculate beam strength for weighting purposes
               wgt = aa.bm_response(i,j).squeeze()
-              # Optimal SNR: down-weight beam-attenuated data 
+              # Optimal SNR: down-weight beam-attenuated data
               # by another factor of the beam response.
               d *= wgt; wgt *= wgt
-          else: wgt = np.ones(d.shape, dtype=np.float)
+          else: wgt = np.ones(d.shape, dtype=np.float64)
           valid = np.logical_and(np.logical_not(f), longenough)
           d = d.compress(valid)
           if len(d) == 0: continue
@@ -243,7 +246,7 @@ for srccnt, s in enumerate(cat.values()):
         grid_it(im,us,vs,ws,ds,wgts)
         uvs,bms,dim,dbm = img_it(im)
     except(ValueError):
-        print 'No data: skipping output file.'
+        print('No data: skipping output file.')
         continue
     for k in ['uvs','bms','dim','dbm']:
         if k in outputs: to_fits(k, eval(k), s, imgcnt,history=history)
@@ -253,5 +256,3 @@ for srccnt, s in enumerate(cat.values()):
         im = a.img.Img(opts.size, opts.res, mf_order=0)
     else:
         im = a.img.ImgW(opts.size, opts.res, mf_order=0, wres=opts.wres)
-    
-
