@@ -1,4 +1,5 @@
-#! /usr/bin/env python
+#!/usr/bin/env python
+
 """
 This is a general-purpose script for making faceted, spherical maps (stored in
 Healpix FITS format) from individual "flat" maps stored in FITS files.
@@ -6,6 +7,8 @@ Healpix FITS format) from individual "flat" maps stored in FITS files.
 Author: Aaron Parsons
 """
 
+from __future__ import print_function, division, absolute_import
+
 import sys, numpy as np, os, aipy as a, optparse, ephem
 
 o = optparse.OptionParser()
@@ -32,21 +35,21 @@ for i, filename in enumerate(args):
     img = img.squeeze()
     # Read ra/dec of image center, which are stored in J2000
     assert(kwds['epoch'] == 2000)
-    s = ephem.Equatorial(kwds['ra']*a.img.deg2rad, kwds['dec']*a.img.deg2rad, 
+    s = ephem.Equatorial(kwds['ra']*a.img.deg2rad, kwds['dec']*a.img.deg2rad,
         epoch=ephem.J2000)
     # To precess the entire image to J2000, we actually need to precess the
     # coords of the center back to the epoch of the observation (obs_date),
     # get the pixel coordinates in that epoch, and then precess the coords of
-    # each pixel.  This is because extrapolating pixel coords from the J2000 
+    # each pixel.  This is because extrapolating pixel coords from the J2000
     # center assumes the J2000 ra/dec axes, which may be tilted relative to
     # the ra/dec axes of the epoch of the image.
     s = ephem.Equatorial(s, epoch=kwds['obs_date'])
     ra, dec = s.get()
-    print '-----------------------------------------------------------'
-    print 'Reading file %s (%d / %d)' % (filename, i + 1, len(args))
-    print kwds
-    print 'Pointing (ra, dec):', ra, dec
-    print 'Image Power:', np.abs(img).sum()
+    print('-----------------------------------------------------------')
+    print('Reading file %s (%d / %d)' % (filename, i + 1, len(args)))
+    print(kwds)
+    print('Pointing (ra, dec):', ra, dec)
+    print('Image Power:', np.abs(img).sum())
     if prev_dra != kwds['d_ra']:
         prev_dra = kwds['d_ra']
         DIM = img.shape[0]
@@ -63,10 +66,9 @@ for i, filename in enumerate(args):
     ex = ex.compress(valid); ey = ey.compress(valid); ez = ez.compress(valid)
     img = img.flatten(); img = img.compress(valid)
     # Precess the pixel coordinates to the (J2000) epoch of the map
-    m = a.coord.convert_m('eq','eq', 
+    m = a.coord.convert_m('eq','eq',
         iepoch=kwds['obs_date'], oepoch=ephem.J2000)
-    ex,ey,ez = np.dot(m, np.array([ex,ey,ez])) 
+    ex,ey,ez = np.dot(m, np.array([ex,ey,ez]))
     # Put the data into the skymap
     skymap.add((ex,ey,ez), map_wgts, img)
 skymap.to_fits(opts.map, clobber=True)
-
