@@ -1,4 +1,5 @@
-#! /usr/bin/env python
+#!/usr/bin/env python
+
 """
 Creates waterfall plots from Miriad UV files.  Can tile multiple plots
 on one window, or plot just a single baseline.  When taking the delay
@@ -11,6 +12,8 @@ output plot (i.e. as specified by --chan_axis and --time_axis).
 Author: Aaron Parsons, Griffin Foster
 """
 
+from __future__ import print_function, division, absolute_import
+
 import aipy as a, numpy as np, sys, optparse
 from matplotlib import pylab as p
 
@@ -130,7 +133,7 @@ plots = {}
 plt_data = {}
 
 for uvfile in args:
-    print 'Reading', uvfile
+    print('Reading', uvfile)
     uv = a.miriad.UV(uvfile)
     if not opts.cal is None:
         aa = a.cal.get_aa(opts.cal, uv['sdf'], uv['sfreq'], uv['nchan'])
@@ -170,10 +173,10 @@ for uvfile in args:
         if opts.delay:
             w = a.dsp.gen_window(d.shape[-1], window=opts.window)
             if opts.unmask:
-                flags = np.ones(d.shape, dtype=np.float)
+                flags = np.ones(d.shape, dtype=np.float64)
                 d = d.data
             else:
-                flags = np.logical_not(d.mask).astype(np.float)
+                flags = np.logical_not(d.mask).astype(np.float64)
                 d = d.filled(0)
             d = np.fft.ifft(d*w)
             ker = np.fft.ifft(flags*w)
@@ -197,7 +200,7 @@ def sort_func(a, b):
     return 1
 bls.sort(cmp=sort_func)
 if len(bls) == 0:
-    print 'No data to plot.'
+    print('No data to plot.')
     sys.exit(0)
 m2 = int(np.sqrt(len(bls)))
 m1 = int(np.ceil(float(len(bls)) / m2))
@@ -233,7 +236,7 @@ for cnt, bl in enumerate(bls):
         label = ''
     else:
         pol = a.miriad.pol2str[pol]
-        label = '%d%s,%d%s ' % (i,pol[0],j,pol[-1]) 
+        label = '%d%s,%d%s ' % (i,pol[0],j,pol[-1])
     if is_chan_range and is_time_range:
         if opts.fringe:
             if opts.time_axis == 'index':
@@ -284,7 +287,7 @@ for cnt, bl in enumerate(bls):
         elif dmin is None: dmin = d.min()
         else: dmin = min(dmin,d.min())
         plots[cnt+1] = p.imshow(d, extent=(c1,c2,t2,t1), origin='upper',
-            aspect='auto', interpolation='nearest', 
+            aspect='auto', interpolation='nearest',
             vmax=dmax, vmin=dmin, cmap=cmap)
         p.colorbar(shrink=0.5)
         p.xlabel(xlabel); p.ylabel(ylabel)
@@ -329,7 +332,7 @@ for cnt, bl in enumerate(bls):
                 drates = np.fft.fftfreq(len(plot_t['cnt']), 1./len(plot_t['cnt']))
                 xlabel = 'Delay-Rate (bins)'
             else:
-                print inttime, len(plot_t['cnt'])
+                print(inttime, len(plot_t['cnt']))
                 drates = np.fft.fftfreq(len(plot_t['cnt']), inttime) * 1e3 # mHz
                 xlabel = 'Delay-Rate (milliHz)'
             plot_times = np.fft.fftshift(drates)
@@ -363,16 +366,16 @@ for cnt, bl in enumerate(bls):
     else: raise ValueError('Either time or chan needs to be a range.')
     if not opts.share:
         pol = a.miriad.pol2str[pol]
-        title = '%d%s,%d%s ' % (i,pol[0],j,pol[-1]) 
+        title = '%d%s,%d%s ' % (i,pol[0],j,pol[-1])
         p.title(title)
-if not opts.nolegend and (not is_time_range or not is_chan_range): 
+if not opts.nolegend and (not is_time_range or not is_chan_range):
     p.legend(loc='best')
 
 # Save to a file or pop up a window
 if opts.out_file != '': p.savefig(opts.out_file)
 else:
     def click(event):
-        print [event.key]
+        print([event.key])
         if event.key == 'm':
             mode = raw_input('Enter new mode: ')
             for k in plots:
@@ -380,7 +383,7 @@ else:
                     d = data_mode(plt_data[k], mode)
                     plots[k].set_data(d)
                 except(ValueError):
-                    print 'Unrecognized plot mode'
+                    print('Unrecognized plot mode')
             p.draw()
         elif event.key == 'd':
             max = raw_input('Enter new max: ')
@@ -396,7 +399,7 @@ else:
                     if _max is None: _max = d.max()
                     if _drng is None: _drng = _max - d.min()
                 plots[k].set_clim(vmin=_max-_drng, vmax=_max)
-            print 'Replotting...'
+            print('Replotting...')
             p.draw()
     p.connect('key_press_event', click)
     p.show()
