@@ -1,4 +1,5 @@
-#! /usr/bin/env python
+#!/usr/bin/env python
+
 """
 Print headers/variables in a Miriad UV file.  If no keywords are provided,
 will print a list of available keywords.
@@ -6,6 +7,8 @@ will print a list of available keywords.
 Author: Aaron Parsons
 """
 
+from __future__ import print_function, division, absolute_import
+
 import aipy as a, sys, optparse
 
 o = optparse.OptionParser()
@@ -16,11 +19,11 @@ o.add_option('-k', '--key', dest='key',
 opts,args = o.parse_args(sys.argv[1:])
 
 for uvfile in args:
-    print uvfile
+    print(uvfile)
     uv = a.miriad.UV(uvfile)
-    if opts.key is None: print '    ', uv.items() + uv.vars()
+    if opts.key is None: print('    ', uv.items() + uv.vars())
     else:
         for key in opts.key.split(','):
-            print '    ', key
-            print '        ', uv[key]
-    print '-----------------------------------------------------------'
+            print('    ', key)
+            print('        ', uv[key])
+    print('-----------------------------------------------------------')
